#!/usr/bin/sh

# Uninstall CCSFL and clean-up /usr/lib64/comodo directory

CCSFL_PREFIX="ccs"
COMODO_DIR="/usr/lib64/comodo"

if [ -f /etc/os-release ]; then
	. /etc/os-release
elif type lsb_release >/dev/null 2>&1; then
    # linuxbase.org
	ID=$(lsb_release -si | tr '[:upper:]' '[:lower:]')
elif [ -f /etc/lsb-release ]; then
    # For some versions of Debian/Ubuntu without lsb_release command
    . /etc/lsb-release
    ID=$( tr '[:upper:]' '[:lover:]' $DISTRIB_ID)
elif [ -f /etc/debian_version ]; then
    ID=debian
elif [ -f /etc/SuSe-release ]; then
    ID=suse
elif [ -f /etc/redhat-release ]; then
    ID=redhat
else
    ID=linux
fi

case $ID in
	ubuntu|debian)
		PKGRMCMD="apt-get purge -y"
		PKG=$(dpkg -l | grep $CCSFL_PREFIX | awk '{print $2}')
		PROMPT="Using apt-get to remove package: $PKG"
		;;
	fedora|centos|redhat|rhel)
		PKGRMCMD="rpm -e"
		PKG=$(rpm -qa | grep $CCSFL_PREFIX)
		PROMPT="Using rpm to remove package: $PKG"
		;;
	suse)
		PKGRMCMD="zypper rm"
		PKG=$(zypper -is | grep $CCSFL_PREFIX)
		PROMPT="Using zypper to remove package: $PKG"
		;;
	*)
		echo "Seems, not supported distribution is used."
		;;
esac

if [ "x$PKGRMCMD" = "x" ]; then
	echo "Can't determine your package manager."
	exit 1;
fi

# do clean up

if [ $(id -u) -ne 0 ]; then
	echo "You are not 'root'."
	exit 1;
fi

# remove package first
if [ "x$PKG" = "x" ]; then
	echo "CCSFL package is not installed on your system.";
else
	echo $PROMPT
	echo "Uninstalling package: $PKG"
	$PKGRMCMD $PKG
fi

# remove /usr/lib64/comodo folder
if [ -d $COMODO_DIR ]; then
	echo "Cleaning up $COMODO_DIR"
	rm -rf $COMODO_DIR
fi
